/*
   Biribot Chassis

   To Do:
   
   Started: March, 1025
   Revision: July, 2015
   
   
   Modules:
      chasis()
      Servo_clamp()
   
   External files:
      params.scad
      Front_axis.scad
      Front_wheel_arm.scad
      Front_wheel.scad
      servo.scad
*/

/*
   Radio de la rueda:   28.0 mm
   Ancho servo:         12.5 mm

   Radio rueda + brida= 34.0 mm

   Radio rueda:         10.0 mm
   Alto soporte:        24.0 mm

   
   El Soporte del Servo va a 7 mm del exterior

*/



include <params.scad>     // Similar to #include



// Modules to be used   
use <Front_axis.scad>  //
use <servo.scad>   
use <Front_wheel_arm.scad>   
use <Front_wheel.scad>
use <Rear_wheel.scad>
use <Battery_pack.scad>
use <Battery_tap.scad>
use <Arduino_holder.scad>


// Test and export as STL
color("DeepPink", .7)
chasis();  //In Spanish, "Chassis" is "chasis"



// Front wheel arms

// Right
color("Grey", .7)
rotate([0,90,0])
translate([-(servo_lz+chasis_lz)/2,-25,-chasis_ly/2-20])
{
   Front_wheel_arm();

   translate([0,0,-20])
   Front_wheel();

   translate([2,chasis_lx-5-6.3,-20])
   Front_wheel();
   
}

//Left
color("Grey", .7)
rotate([0,-90,0])
translate([(servo_lz+chasis_lz)/2,-25,-chasis_ly/2-20])
{
   Front_wheel_arm();
   
   translate([0,0,-20])
   Front_wheel();
   
   translate([0,chasis_lx-5-6.3,-20])
   Front_wheel();
}



//Battery holder
rotate([180,0,90])

translate([7,0,15])
{
color("Red", .7)
battery_holder(1,4);

//Battery Tap
color("Yellow", .7)
translate([0,0,25])
Battery_tap();

//Battery Tap
translate([0,0,40])
color("Green", .7)
Arduino_holder();

}



//Servos

// Left Servo
translate([(9.5+25),+chasis_ly/2-5,servo_lz+chasis_lz/2])  
rotate([-90,0,-90])

servoSG90();


// Right Servo
translate([-(9.5+25),+chasis_ly/2-5,0])
rotate([90,0,-90])
servoSG90();




/*
   Module: Chasis()
*/
module chasis()
{
   
   // Plate minus washer's drill
   difference()
   { 
      //Plate: Simple rectangle + circle
      union()
      {
         cube( [chasis_lx, chasis_ly,chasis_lz], center= true);
         
         translate([0,-chasis_ly/2,-chasis_lz/2])
         cylinder( r=20/2,h=chasis_lz,$fn=resolution);
      }
  
      // Washer's drill
      translate([0,-chasis_ly/2,-chasis_lz/2-1])
      cylinder(r=3/2,h=10,$fn=50);
   
      translate([0,-chasis_ly/2,0])
      cylinder(r=4.5/2,h=10,$fn=6);

   }
   // End chassis

   // Front axis
   translate([0,-25,servo_lz/2+(chasis_lz)/2])
   rotate([90,-90,90])
   Front_axis();
   
   // Servo clamps
   
   //Left servo
   
   //Clamp 1
   translate([chasis_lx/2-servo_a_ext,chasis_ly/2-5,0])
   Servo_clamp();
   //Clamp 2
   translate([chasis_lx/2-servo_a_ext,chasis_ly/2-servo_ly-10,0])
   Servo_clamp();

   //Right servo
   
   // Clamp 1
   translate([-chasis_lx/2+servo_a_ext,chasis_ly/2,0])
   rotate([0,0,180])
   Servo_clamp();
   //Clamp 2
   translate([-chasis_lx/2+servo_a_ext,chasis_ly/2-servo_ly-5,0])
   rotate([0,0,180])
   Servo_clamp();
}



/*
   Module: Chasis()

   No need to be parametrized 
*/
module Servo_clamp()
{

   rotate([-90,0,0])

   translate([0,-14.2,0])
   difference()
   {
      cube([16,servo_lz,5]);
      cylinder( r=20/2,h=5,$fn=resolution);
   }
}



